==> ingdao-0.0.19.tar.gz: lib/dataflow/field/dfstringvalidator.dart <==
import 'dfvalidator.dart';
import '../control/dfresponse.dart';

class MinLenValidateException extends DfError {
   MinLenValidateException(int minLen) : super(code: 10002, message: "Input length is less than min length: $minLen required.");
}

class MaxLenValidateException extends DfError {
   MaxLenValidateException(int maxLen) : super(code: 10003, message: "Input length is more than max length: $maxLen allowed.");
}

class EmailValidateException extends DfError {
   EmailValidateException() : super(code: 10004, message: "Invalid email address.");
}

class AlphaValidateException extends DfError {
   AlphaValidateException() : super(code: 10005, message: "Input must be alphabetic only.");
}

class AlphaSpaceValidateException extends DfError {
   AlphaSpaceValidateException() : super(code: 10006, message: "Input must be alphabetic or space only.");
}

class DigitValidateException extends DfError {
   DigitValidateException() : super(code: 10007, message: "Input must be digit character only.");
}

class NumericValidateException extends DfError {
   NumericValidateException() : super(code: 10008, message: "Input must be numeric character only.");
}

class AlphaDigitValidateException extends DfError {
   AlphaDigitValidateException() : super(code: 10009, message: "Input must be alphabetic or digit character only.");
}

class CustomInputValidateException extends DfError {
   CustomInputValidateException() : super(code: 10010, message: "Invalid input format.");
}

class AlphaSpaceDigitValidateException extends DfError {
   AlphaSpaceDigitValidateException() : super(code: 10011, message: "Input must be alphabetic, digit or space only.");
}

class DfStringValidator extends DfValidator {

  int minLen;
  int maxLen;
  bool isEmail = false;
  bool isAlphaOnly = false;
  bool isAlphaAndSpaceOnly = false;
  bool isDigit = false;
  bool isNumeric = false;
  bool isAlphaDigit = false;
  bool isAlphaAndSpaceAndDigitOnly = false;
  String customRegExprValidate;

  DfStringValidator({bool isAllowEmpty = true, this.minLen, this.maxLen, this.isEmail = false, this.isAlphaOnly = false, this.isAlphaAndSpaceOnly = false, this.isDigit = false, this.isNumeric = false, this.isAlphaDigit = false, this.isAlphaAndSpaceAndDigitOnly = false, this.customRegExprValidate}) : super(isAllowEmpty: isAllowEmpty);

  MinLenValidateException minLenValidate() {
    if (emptyValidate() == null && minLen != null) {
      String strVal = field.value.toString();
      return strVal.length < minLen ? MinLenValidateException(minLen) : null;
    }
    return null;
  }

  MaxLenValidateException maxLenValidate() {
    if (emptyValidate() == null && maxLen != null) {      
      String strVal = field.value.toString();
      return strVal.length > maxLen ? MaxLenValidateException(maxLen) : null;
    }
    return null;
  }

  EmailValidateException emailValidate() {
    if (emptyValidate() == null && isEmail) {
      String strVal = field.value.toString();
      bool emailValid = RegExp(r"^[a-zA-Z0-9.a-zA-Z0-9.!#$%&'*+-/=?^_`{|}~]+@[a-zA-Z0-9]+\.[a-zA-Z]+").hasMatch(strVal);
      return !emailValid ? EmailValidateException() : null;
    }
    return null;
  }

  AlphaValidateException alphaValidate() {
    if (emptyValidate() == null && isAlphaOnly) {
      String strVal = field.value.toString();
      bool valid = RegExp(r'^[a-zA-Z]+$').hasMatch(strVal);
      return !valid ? AlphaValidateException() : null;
    }
    return null;
  }

  AlphaSpaceValidateException alphaSpaceValidate() {
    if (emptyValidate() == null && isAlphaAndSpaceOnly) {
      String strVal = field.value.toString();
      bool valid = RegExp(r'^[a-zA-Z\s]+$').hasMatch(strVal);
      return !valid ? AlphaSpaceValidateException() : null;
    }
    return null;
  }

    AlphaSpaceDigitValidateException alphaSpaceDigitValidate() {
    if (emptyValidate() == null && isAlphaAndSpaceAndDigitOnly) {
      String strVal = field.value.toString();
      bool valid = RegExp(r'^[a-zA-Z0-9\s]+$').hasMatch(strVal);
      return !valid ? AlphaSpaceDigitValidateException() : null;
    }
    return null;
  }

  DigitValidateException digitValidate() {
    if (emptyValidate() == null && isDigit) {
      String strVal = field.value.toString();
      bool valid = RegExp(r'^[0-9]+$').hasMatch(strVal);
      return !valid ? DigitValidateException() : null;
    }
    return null;
  }

  NumericValidateException numericValidate() {
    if (emptyValidate() == null && isNumeric) {
      String strVal = field.value.toString();
      bool valid = double.tryParse(strVal) != null;
      return !valid ? NumericValidateException() : null;
    }
    return null;
  }

  AlphaDigitValidateException alphaDigitValidate() {
    if (emptyValidate() == null && isAlphaDigit) {
      String strVal = field.value.toString();
      bool valid = RegExp(r'^[a-zA-Z0-9]+$').hasMatch(strVal);
      return !valid ? AlphaDigitValidateException() : null;
    }
    return null;
  }

  CustomInputValidateException customInputValidate() {
    if (emptyValidate() == null && customRegExprValidate != null) {
      String strVal = field.value.toString();
      bool valid = RegExp(r"" + customRegExprValidate).hasMatch(strVal);
      return !valid ? CustomInputValidateException() : null;
    }
    return null;
  }

  List<DfError> validate() {
    List<DfError> errors = List<DfError>();
    DfError emptyErr = emptyValidate();
    if (emptyErr != null) {
      errors.add(emptyErr);
    }

    DfError minLenErr = minLenValidate();
    if (minLenErr != null) {
      errors.add(minLenErr);
    }

    DfError maxLenErr = maxLenValidate();
    if (maxLenErr != null) {
      errors.add(maxLenErr);
    }

    DfError emailErr = emailValidate();
    if (emailErr != null) {
      errors.add(emailErr);
    }

    DfError alphaErr = alphaValidate();
    if (alphaErr != null) {
      errors.add(alphaErr);
    }

    DfError alphaSpaceErr = alphaSpaceValidate();
    if (alphaSpaceErr != null) {
      errors.add(alphaSpaceErr);
    }

    DfError digitErr = digitValidate();
    if (digitErr != null) {
      errors.add(digitErr);
    }

    DfError numericErr = numericValidate();
    if (numericErr != null) {
      errors.add(numericErr);
    }

    DfError alphaDigitErr = alphaDigitValidate();
    if (alphaDigitErr != null) {
      errors.add(alphaDigitErr);
    }

    DfError customErr = customInputValidate();
    if (customErr != null) {
      errors.add(customErr);
    }

    return errors.length > 0 ? errors : null;
  }

}

==> ingdao-0.0.28.tar.gz: lib/dataflow/field/dfstringvalidator.dart <==
import 'dfvalidator.dart';
import '../control/dfresponse.dart';

class MinLenValidateException extends DfError {
   MinLenValidateException(String val, int minLen) : super(code: 10002, message: "Input: \"$val\" length: ${val != null ? val.length : 0} is less than min length: $minLen required.");
}

class MaxLenValidateException extends DfError {
   MaxLenValidateException(String val, int maxLen) : super(code: 10003, message: "Input: \"$val\" length: ${val != null ? val.length : 0} is more than max length: $maxLen allowed.");
}

class EmailValidateException extends DfError {
   EmailValidateException(String val) : super(code: 10004, message: "Invalid email address: \"$val\"");
}

class AlphaValidateException extends DfError {
   AlphaValidateException(String val) : super(code: 10005, message: "Input: \"$val\" must be alphabetic only.");
}

class AlphaSpaceValidateException extends DfError {
   AlphaSpaceValidateException(String val) : super(code: 10006, message: "Input: \"$val\" must be alphabetic or space only.");
}

class DigitValidateException extends DfError {
   DigitValidateException(String val) : super(code: 10007, message: "Input: \"$val\" must be digit character only.");
}

class NumericValidateException extends DfError {
   NumericValidateException(String val) : super(code: 10008, message: "Input: \"$val\" must be numeric character only.");
}

class AlphaDigitValidateException extends DfError {
   AlphaDigitValidateException(String val) : super(code: 10009, message: "Input: \"$val\" must be alphabetic or digit character only.");
}

class CustomInputValidateException extends DfError {
   CustomInputValidateException(String val) : super(code: 10010, message: "Input: \"$val\", Invalid input format.");
}

class AlphaSpaceDigitValidateException extends DfError {
   AlphaSpaceDigitValidateException(String val) : super(code: 10011, message: "Input: \"$val\" must be alphabetic, digit or space only.");
}

class DfStringValidator extends DfValidator {

  int minLen;
  int maxLen;
  bool isEmail = false;
  bool isAlphaOnly = false;
  bool isAlphaAndSpaceOnly = false;
  bool isDigit = false;
  bool isNumeric = false;
  bool isAlphaDigit = false;
  bool isAlphaAndSpaceAndDigitOnly = false;
  String customRegExprValidate;

  DfStringValidator({bool isAllowEmpty = true, this.minLen, this.maxLen, this.isEmail = false, this.isAlphaOnly = false, this.isAlphaAndSpaceOnly = false, this.isDigit = false, this.isNumeric = false, this.isAlphaDigit = false, this.isAlphaAndSpaceAndDigitOnly = false, this.customRegExprValidate}) : super(isAllowEmpty: isAllowEmpty);

  MinLenValidateException minLenValidate() {
    if (emptyValidate() == null && minLen != null) {
      String strVal = field.value.toString();
      return strVal.length < minLen ? MinLenValidateException(strVal,minLen) : null;
    }
    return null;
  }

  MaxLenValidateException maxLenValidate() {
    if (emptyValidate() == null && maxLen != null) {      
      String strVal = field.value.toString();
      return strVal.length > maxLen ? MaxLenValidateException(strVal,maxLen) : null;
    }
    return null;
  }

  EmailValidateException emailValidate() {
    if (emptyValidate() == null && isEmail) {
      String strVal = field.value.toString();
      bool emailValid = RegExp(r"^[a-zA-Z0-9.a-zA-Z0-9.!#$%&'*+-/=?^_`{|}~]+@[a-zA-Z0-9]+\.[a-zA-Z]+").hasMatch(strVal);
      return !emailValid ? EmailValidateException(strVal) : null;
    }
    return null;
  }

  AlphaValidateException alphaValidate() {
    if (emptyValidate() == null && isAlphaOnly) {
      String strVal = field.value.toString();
      bool valid = RegExp(r'^[a-zA-Z]+$').hasMatch(strVal);
      return !valid ? AlphaValidateException(strVal) : null;
    }
    return null;
  }

  AlphaSpaceValidateException alphaSpaceValidate() {
    if (emptyValidate() == null && isAlphaAndSpaceOnly) {
      String strVal = field.value.toString();
      bool valid = RegExp(r'^[a-zA-Z\s]+$').hasMatch(strVal);
      return !valid ? AlphaSpaceValidateException(strVal) : null;
    }
    return null;
  }

    AlphaSpaceDigitValidateException alphaSpaceDigitValidate() {
    if (emptyValidate() == null && isAlphaAndSpaceAndDigitOnly) {
      String strVal = field.value.toString();
      bool valid = RegExp(r'^[a-zA-Z0-9\s]+$').hasMatch(strVal);
      return !valid ? AlphaSpaceDigitValidateException(strVal) : null;
    }
    return null;
  }

  DigitValidateException digitValidate() {
    if (emptyValidate() == null && isDigit) {
      String strVal = field.value.toString();
      bool valid = RegExp(r'^[0-9]+$').hasMatch(strVal);
      return !valid ? DigitValidateException(strVal) : null;
    }
    return null;
  }

  NumericValidateException numericValidate() {
    if (emptyValidate() == null && isNumeric) {
      String strVal = field.value.toString();
      bool valid = double.tryParse(strVal) != null;
      return !valid ? NumericValidateException(strVal) : null;
    }
    return null;
  }

  AlphaDigitValidateException alphaDigitValidate() {
    if (emptyValidate() == null && isAlphaDigit) {
      String strVal = field.value.toString();
      bool valid = RegExp(r'^[a-zA-Z0-9]+$').hasMatch(strVal);
      return !valid ? AlphaDigitValidateException(strVal) : null;
    }
    return null;
  }

  CustomInputValidateException customInputValidate() {
    if (emptyValidate() == null && customRegExprValidate != null) {
      String strVal = field.value.toString();
      bool valid = RegExp(r"" + customRegExprValidate).hasMatch(strVal);
      return !valid ? CustomInputValidateException(strVal) : null;
    }
    return null;
  }

  List<DfError> validate() {
    List<DfError> errors = [];
    DfError emptyErr = emptyValidate();
    if (emptyErr != null) {
      errors.add(emptyErr);
    }

    DfError minLenErr = minLenValidate();
    if (minLenErr != null) {
      errors.add(minLenErr);
    }

    DfError maxLenErr = maxLenValidate();
    if (maxLenErr != null) {
      errors.add(maxLenErr);
    }

    DfError emailErr = emailValidate();
    if (emailErr != null) {
      errors.add(emailErr);
    }

    DfError alphaErr = alphaValidate();
    if (alphaErr != null) {
      errors.add(alphaErr);
    }

    DfError alphaSpaceErr = alphaSpaceValidate();
    if (alphaSpaceErr != null) {
      errors.add(alphaSpaceErr);
    }

    DfError digitErr = digitValidate();
    if (digitErr != null) {
      errors.add(digitErr);
    }

    DfError numericErr = numericValidate();
    if (numericErr != null) {
      errors.add(numericErr);
    }

    DfError alphaDigitErr = alphaDigitValidate();
    if (alphaDigitErr != null) {
      errors.add(alphaDigitErr);
    }

    DfError customErr = customInputValidate();
    if (customErr != null) {
      errors.add(customErr);
    }

    return errors.length > 0 ? errors : null;
  }

}
